# niutrader
> 由于easytrader无法使用，精简了其中功能，只保留了同花顺客户端交易功能。已经修复了其中的错误，验证码识别正常。

同花顺自动化交易系统

## 同花顺-网上股票交易系统5.0设置

1. 交易设置--默认交易费率--万一；
2. 交易设置--默认买入价格/买入数量/卖出价格/卖出数量 都设置为 空
3. 界面设置--显示悬浮工具栏--否

## 使用流程
1. 安装依赖：`pip install -r requirements.txt`
2. 安装验证码识别工具tesseract，并添加到系统环境变量
   - 官方链接：https://github.com/tesseract-ocr/tesseract
   - 安装文档：https://tesseract-ocr.github.io/tessdoc/Installation.html
3. 打开同花顺，登陆自己的资金账户，按上面设置一下
4. 编写代码，测试连接同花顺客户端